@@ -17,6 +17,10 @@
 #include <QFileInfo>
 
 using namespace KCalendarCore;
+namespace
+{
+static const char mySuspensedGroupName[] = "Suspended";
+}
 
 KalendarAlarmClient::KalendarAlarmClient(QObject *parent)
     : QObject(parent)
@@ -83,7 +87,7 @@ void KalendarAlarmClient::deferredInit()
         return;
     }
 
-    qCDebug(Log) << "Performing delayed initialization.";
+    qCDebug(REMINDER_DAEMON_LOG) << "Performing delayed initialization.";
 
     KCheckableProxyModel *checkableModel = mCalendar->checkableProxyModel();
     checkAllItems(checkableModel);
@@ -94,8 +98,8 @@ void KalendarAlarmClient::deferredInit()
 
 void KalendarAlarmClient::restoreSuspendedFromConfig()
 {
-    qCDebug(Log) << "Restore suspended alarms from config";
-    const KConfigGroup suspendedGroup(KSharedConfig::openConfig(), "Suspended");
+    qCDebug(REMINDER_DAEMON_LOG) << "Restore suspended alarms from config";
+    const KConfigGroup suspendedGroup(KSharedConfig::openConfig(), mySuspensedGroupName);
     const auto suspendedAlarms = suspendedGroup.groupList();
 
     for (const auto &s : suspendedAlarms) {
@@ -104,17 +108,18 @@ void KalendarAlarmClient::restoreSuspendedFromConfig()
         const QString txt = suspendedAlarm.readEntry("Text");
         const QDateTime occurrence = suspendedAlarm.readEntry("Occurrence", QDateTime());
         const QDateTime remindAt = suspendedAlarm.readEntry("RemindAt", QDateTime());
-        qCDebug(Log) << "restoreSuspendedFromConfig: Restoring alarm" << uid << "," << txt << "," << remindAt;
+        const bool wasSuspended = suspendedAlarm.readEntry("WasSuspensed", false);
+        qCDebug(REMINDER_DAEMON_LOG) << "restoreSuspendedFromConfig: Restoring alarm" << uid << "," << txt << "," << remindAt;
 
         if (!uid.isEmpty() && remindAt.isValid()) {
-            addNotification(uid, txt, occurrence, remindAt);
+            addNotification(uid, txt, occurrence, remindAt, wasSuspended);
         }
     }
 }
 
 void KalendarAlarmClient::dismiss(AlarmNotification *notification)
 {
-    qCDebug(Log) << "Alarm" << notification->uid() << "dismissed";
+    qCDebug(REMINDER_DAEMON_LOG) << "Alarm" << notification->uid() << "dismissed";
     removeNotification(notification);
     m_notifications.remove(notification->uid());
     delete notification;
@@ -122,8 +127,9 @@ void KalendarAlarmClient::dismiss(AlarmNotification *notification)
 
 void KalendarAlarmClient::suspend(AlarmNotification *notification, std::chrono::seconds sec)
 {
-    qCDebug(Log) << "Alarm " << notification->uid() << "suspended";
+    qCDebug(REMINDER_DAEMON_LOG) << "Alarm " << notification->uid() << "suspended";
     notification->setRemindAt(QDateTime(QDateTime::currentDateTime()).addSecs(sec.count()));
+    notification->setWasSuspended(true);
     storeNotification(notification);
 }
 
@@ -169,7 +175,7 @@ void KalendarAlarmClient::storeNotification(AlarmNotification *notification)
     const auto notificationUidUtf8 = notification->uid().toUtf8();
     const auto notificationUidData = notificationUidUtf8.constData();
 
-    KConfigGroup suspendedGroup(KSharedConfig::openConfig(), "Suspended");
+    KConfigGroup suspendedGroup(KSharedConfig::openConfig(), mySuspensedGroupName);
     KConfigGroup notificationGroup(&suspendedGroup, notificationUidData);
     notificationGroup.writeEntry("UID", notificationUidData);
     notificationGroup.writeEntry("Text", notification->text());
@@ -177,6 +183,7 @@ void KalendarAlarmClient::storeNotification(AlarmNotification *notification)
         notificationGroup.writeEntry("Occurrence", notification->occurrence());
     }
     notificationGroup.writeEntry("RemindAt", notification->remindAt());
+    notificationGroup.writeEntry("WasSuspensed", notification->wasSuspended());
     KSharedConfig::openConfig()->sync();
 }
 
@@ -187,13 +194,13 @@ void KalendarAlarmClient::removeNotification(AlarmNotification *notification)
     const auto notificationUidUtf8 = notification->uid().toUtf8();
     const auto notificationUidData = notificationUidUtf8.constData();
 
-    KConfigGroup suspendedGroup(KSharedConfig::openConfig(), "Suspended");
+    KConfigGroup suspendedGroup(KSharedConfig::openConfig(), mySuspensedGroupName);
     KConfigGroup notificationGroup(&suspendedGroup, notificationUidData);
     notificationGroup.deleteGroup();
     KSharedConfig::openConfig()->sync();
 }
 
-void KalendarAlarmClient::addNotification(const QString &uid, const QString &text, const QDateTime &occurrence, const QDateTime &remindTime)
+void KalendarAlarmClient::addNotification(const QString &uid, const QString &text, const QDateTime &occurrence, const QDateTime &remindTime, bool wasSuspended)
 {
     AlarmNotification *notification = nullptr;
     const auto it = m_notifications.constFind(uid);
@@ -209,10 +216,11 @@ void KalendarAlarmClient::addNotification(const QString &uid, const QString &tex
     }
 
     // we either have no notification for this event yet, or one that is scheduled for later and that should be replaced
-    qCDebug(Log) << "Adding notification, uid:" << uid << "text:" << text << "remindTime:" << remindTime;
+    qCDebug(REMINDER_DAEMON_LOG) << "Adding notification, uid:" << uid << "text:" << text << "remindTime:" << remindTime;
     notification->setText(text);
     notification->setOccurrence(occurrence);
     notification->setRemindAt(remindTime);
+    notification->setWasSuspended(wasSuspended);
     m_notifications[notification->uid()] = notification;
     storeNotification(notification);
 }
@@ -243,14 +251,14 @@ void KalendarAlarmClient::checkAlarms()
     // We do not want to miss any reminders, so don't perform check unless
     // the collections are available and populated.
     if (!collectionsAvailable()) {
-        qCDebug(Log) << "Collections are not available; aborting check.";
+        qCDebug(REMINDER_DAEMON_LOG) << "Collections are not available; aborting check.";
         return;
     }
 
     const QDateTime from = mLastChecked.addSecs(1);
     mLastChecked = QDateTime::currentDateTime();
 
-    qCDebug(Log) << "Check:" << from.toString() << " -" << mLastChecked.toString();
+    qCDebug(REMINDER_DAEMON_LOG) << "Check:" << from.toString() << " -" << mLastChecked.toString();
 
     // look for new alarms
     const Alarm::List alarms = mCalendar->alarms(from, mLastChecked, true /* exclude blocked alarms */);
@@ -259,9 +267,9 @@ void KalendarAlarmClient::checkAlarms()
         const auto incidence = mCalendar->incidence(uid);
         if (incidence) {
             const auto occurrence = occurrenceForAlarm(incidence, alarm, from);
-            addNotification(uid, alarm->text(), occurrence, mLastChecked);
+            addNotification(uid, alarm->text(), occurrence, mLastChecked, false);
         } else {
-            qCDebug(Log) << "Alarm points" << alarm << "to an nonexisting incidence" << uid;
+            qCDebug(REMINDER_DAEMON_LOG) << "Alarm points" << alarm << "to an nonexisting incidence" << uid;
         }
     }
 
@@ -276,7 +284,7 @@ void KalendarAlarmClient::checkAlarms()
 
         // Protect against null ptr
         if (!notification) {
-            qCDebug(Log) << "Found null active alarm with id: " << it.key() << "Skipping.";
+            qCDebug(REMINDER_DAEMON_LOG) << "Found null active alarm with id: " << it.key() << "Skipping.";
             nullAlarmNotificationIds.append(it.key());
             continue;
         }
