@@ -11,7 +11,6 @@
 #include <KEMailSettings>
 #include <KEmailAddress>
 #include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Utils>
 #include <KMime/HeaderParsing>
 
@@ -98,14 +97,3 @@ QStringList Akonadi::CalendarUtils::allEmails()
     }
     return emails;
 }
-
-KCalendarCore::Incidence::Ptr Akonadi::CalendarUtils::incidence(const Akonadi::Item &item)
-{
-    // With this try-catch block, we get a 2x performance improvement in retrieving the payload
-    // since we don't call hasPayload()
-    try {
-        return item.payload<KCalendarCore::Incidence::Ptr>();
-    } catch (const Akonadi::PayloadException &) {
-        return {};
-    }
-}
